# Calvos-Engine Release Notes

**Release Version:** 0.0.5b

**Release Maturity:** beta

**Change Log:**

- Fix: Timeout timer not getting reset upon reception of CAN message in function "can_NWID_NODEID_processRxMessage".

**Known errors:**

**Check List**

| Id   | Item                                                         | Compliant (OK / NOK / N.A.) | Comments |
| ---- | ------------------------------------------------------------ | --------------------------- | -------- |
| 1    | Is the \_\_version\_\_.py module updated with the proper version number? | OK                          |          |
| 2    | In \_\_main\_\_.py are variables "\_\_date\_\_ " and "\_\_updated\_\_" updated? | OK                          |          |
| 3    | In \_\_main\_\_.py are constants "DEBUG", "TESTRUN" and "PROFILE" set to zero? | OK                          |          |
| 4    | Is the manual "comgen_CAN - Integration Manual.md" applicable version text up-to-date? Is the pdf version of it generated? | OK                          |          |
| 5    | is the "README.md" within the "calvos engine" (visible in PyPi) folder up-to-date (arguments description, examples, etc.) and without reference to the calvos logo? | OK                          |          |
| 6    | is the "README.md" within the "calvos" folder (visible in github) up-to-date (arguments description, examples, etc.) and with reference to the calvos logo? | OK                          |          |
| 7    | Does the engine runs without any error?                      | OK                          |          |
| 8    | Is the demo project generated and processed with no errors/warnings from the engine? | OK                          |          |
| 9    | Does the generated demo project compiles with no errors in a target project? | OK                          |          |
| 10   | Is the latest code commited to github?                       | OK                          |          |

